@@ -8,7 +8,7 @@ use Amazon::SQS::Simple::Base; # for constants
 use Amazon::SQS::Simple::Queue;
 use base qw(Exporter Amazon::SQS::Simple::Base);
 
-our $VERSION   = '1.03';
+our $VERSION   = '1.04';
 our @EXPORT_OK = qw( timestamp );
 
 sub GetQueue {
@@ -27,24 +27,12 @@ sub CreateQueue {
         
     my $href = $self->_dispatch(\%params);
     
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        if ($href->{QueueUrl}) {
-            return Amazon::SQS::Simple::Queue->new(
-                %$self,
-                Endpoint => $href->{QueueUrl},
-            );
-        }
+    if ($href->{CreateQueueResult}{QueueUrl}) {
+        return Amazon::SQS::Simple::Queue->new(
+            %$self,
+            Endpoint => $href->{CreateQueueResult}{QueueUrl},
+        );
     }
-    else {
-        # default to the most recent version
-        if ($href->{CreateQueueResult}{QueueUrl}) {
-            return Amazon::SQS::Simple::Queue->new(
-                %$self,
-                Endpoint => $href->{CreateQueueResult}{QueueUrl},
-            );
-        }
-    }
-    
 }
 
 sub ListQueues {
@@ -54,35 +42,19 @@ sub ListQueues {
         
     my $href = $self->_dispatch(\%params, ['QueueUrl']);
     
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        if ($href->{QueueUrl}) {
-            my @result = map {
-                new Amazon::SQS::Simple::Queue(
-                    %$self,
-                    Endpoint => $_,
-                )        
-            } @{$href->{QueueUrl}};
-            return \@result;
-        }
-        else {
-            return undef;
-        }
+    # default to the current version
+    if ($href->{ListQueuesResult}{QueueUrl}) {
+        my @result = map {
+            new Amazon::SQS::Simple::Queue(
+                %$self,
+                Endpoint => $_,
+            )        
+        } @{$href->{ListQueuesResult}{QueueUrl}};
+
+        return \@result;
     }
     else {
-        # default to the current version
-        if ($href->{ListQueuesResult}{QueueUrl}) {
-            my @result = map {
-                new Amazon::SQS::Simple::Queue(
-                    %$self,
-                    Endpoint => $_,
-                )        
-            } @{$href->{ListQueuesResult}{QueueUrl}};
-
-            return \@result;
-        }
-        else {
-            return undef;
-        }
+        return undef;
     }
 }
 
@@ -132,19 +104,10 @@ Amazon::SQS::Simple is an OO API for the Amazon Simple Queue Service.
 =head1 IMPORTANT
 
 This version of Amazon::SQS::Simple defaults to work against version
-2008-01-01 of the SQS API.
+2009-02-01 of the SQS API.
 
 Earlier API versions may or may not work.  
 
-Actions dropped in recent versions will be dropped.  Sometimes
-compatiblity among the Actions is not possible, e.g. Delete in
-2007-05-01 takes a MessageId and in 2008-01-01 takes a ReceiptHandle.
-We change the request parameters based on the SQS API version, it is
-up to the caller to pass the correct value.
-
-Bear in mind that earlier SQS versions are slated for deprecation -
-see aws.amazon.com for details.
-
 =head1 CONSTRUCTOR
 
 =over 2
@@ -160,9 +123,7 @@ L<http://aws.amazon.com/>.
 You may specify an optional named argument for the version of the SQS
 API you wish to use.  This allows loading older data.  E.g.:
 
- my $sqs = new Amazon::SQS::Simple($access_key, $secret_key, Version => '2007-05-01');
-
-This is not guaranteed to work for all older versions.  See IMPORTANT above.
+ my $sqs = new Amazon::SQS::Simple($access_key, $secret_key, Version => '2008-01-01');
 
 =back
 
