@@ -11,15 +11,14 @@ use XML::Simple;
 
 use base qw(Exporter);
 
+use constant SQS_VERSION_2009_02_01 => '2009-02-01';
 use constant SQS_VERSION_2008_01_01 => '2008-01-01';
-use constant SQS_VERSION_2007_05_01 => '2007-05-01';
 use constant BASE_ENDPOINT          => 'http://queue.amazonaws.com';
 use constant MAX_GET_MSG_SIZE       => 4096; # Messages larger than this size will be sent
-                                             # using a POST request. This feature requires
-                                             # SQS_VERSION 2007-05-01 or later.
+                                             # using a POST request.
                                        
-our $DEFAULT_SQS_VERSION = +SQS_VERSION_2008_01_01;
-our @EXPORT = qw(SQS_VERSION_2008_01_01 SQS_VERSION_2007_05_01);
+our $DEFAULT_SQS_VERSION = +SQS_VERSION_2009_02_01;
+our @EXPORT = qw(SQS_VERSION_2009_02_01 SQS_VERSION_2008_01_01);
 
 sub new {
     my $class = shift;
@@ -40,7 +39,7 @@ sub new {
     }
 
     # validate the Version, warn if it's not one we recognise
-    my @valid_versions = ( +SQS_VERSION_2007_05_01, +SQS_VERSION_2008_01_01 );
+    my @valid_versions = ( +SQS_VERSION_2008_01_01, +SQS_VERSION_2009_02_01 );
     if (!grep {$self->{Version} eq $_} @valid_versions) {
         carp "Warning: " 
            . $self->{Version} 
@@ -106,9 +105,7 @@ sub _dispatch {
         my $msg;
         eval {
             my $href = XMLin($response->content);
-            $msg = $self->_api_version eq +SQS_VERSION_2007_05_01 
-                 ? $href->{Errors}{Error}{Message} 
-                 : $href->{Error}{Message};
+            $msg = $href->{Error}{Message};
         };
         
         my $error = "ERROR: On calling $params->{Action}: " . $response->status_line;
