@@ -4,6 +4,7 @@ use strict;
 use warnings;
 use Amazon::SQS::Simple::Message;
 use Amazon::SQS::Simple::SendResponse;
+use Carp qw( croak carp );
 
 use base 'Amazon::SQS::Simple::Base';
 use Amazon::SQS::Simple::Base; # for constants
@@ -17,9 +18,7 @@ sub Endpoint {
 
 sub Delete {
     my $self = shift;
-    my $force = shift; # from API 2007-05-01
     my $params = { Action => 'DeleteQueue' };
-    $params->{ForceDeletion} = 'true' if $force && $self->_api_version() eq +SQS_VERSION_2007_05_01;
     
     my $href = $self->_dispatch($params);    
 }
@@ -32,17 +31,10 @@ sub SendMessage {
     
     my $href = $self->_dispatch(\%params);    
 
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        return new Amazon::SQS::Simple::SendResponse(
-            $href
-        );
-    }
-    else {
-        # default to most recent version
-        return new Amazon::SQS::Simple::SendResponse(
-            $href->{SendMessageResult}
-        );
-    }
+    # default to most recent version
+    return new Amazon::SQS::Simple::SendResponse(
+        $href->{SendMessageResult}
+    );
 }
 
 sub ReceiveMessage {
@@ -54,25 +46,13 @@ sub ReceiveMessage {
 
     my @messages = ();
 
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        if (defined $href->{Message}) {
-            foreach (@{$href->{Message}}) {
-                push @messages, new Amazon::SQS::Simple::Message(
-                    $_,
-                    $self->_api_version()
-                );
-            }
-        }
-    }
-    else {
-        # default to most recent version
-        if (defined $href->{ReceiveMessageResult}{Message}) {
-            foreach (@{$href->{ReceiveMessageResult}{Message}}) {
-                push @messages, new Amazon::SQS::Simple::Message(
-                    $_,
-                    $self->_api_version()
-                );
-            }
+    # default to most recent version
+    if (defined $href->{ReceiveMessageResult}{Message}) {
+        foreach (@{$href->{ReceiveMessageResult}{Message}}) {
+            push @messages, new Amazon::SQS::Simple::Message(
+                $_,
+                $self->_api_version()
+            );
         }
     }
     
@@ -89,47 +69,94 @@ sub DeleteMessage {
     my ($self, $receipt_handle, %params) = @_;
     
     $params{Action} = 'DeleteMessage';
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        $params{MessageId} = $receipt_handle;
-    }
-    else {
-        # default to the current version
-        $params{ReceiptHandle} = $receipt_handle;
-    }
+    $params{ReceiptHandle} = $receipt_handle;
     
     my $href = $self->_dispatch(\%params);
 }
 
+sub ChangeMessageVisibility {
+    my ($self, $receipt_handle, $timeout, %params) = @_;
+    
+    if ($self->_api_version eq +SQS_VERSION_2008_01_01) {
+        carp "ChangeMessageVisibility not supported in this API version";
+    }
+    else {
+        if (!defined($timeout) || $timeout =~ /\D/ || $timeout < 0 || $timeout > 43200) {
+            croak "timeout must be specified and in range 0..43200";
+        }
+
+        $params{Action}             = 'ChangeMessageVisibility';
+        $params{ReceiptHandle}      = $receipt_handle;
+        $params{VisibilityTimeout}  = $timeout;
+
+        my $href = $self->_dispatch(\%params);
+    }
+}
+
+our %valid_permission_actions = map { $_ => 1 } qw(* SendMessage ReceiveMessage DeleteMessage ChangeMessageVisibility GetQueueAttributes);
+
+sub AddPermission {
+    my ($self, $label, $account_actions, %params) = @_;
+    
+    if ($self->_api_version eq +SQS_VERSION_2008_01_01) {
+        carp "AddPermission not supported in this API version";
+    }
+    else {
+        $params{Action} = 'AddPermission';
+        $params{Label}  = $label;
+        my $i = 1;
+        foreach my $account_id (keys %$account_actions) {
+            $account_id =~ /^\d{12}$/ or croak "Account IDs passed to AddPermission should be 12 digit AWS account numbers, no hyphens";
+            my $actions = $account_actions->{$account_id};
+            my @actions;
+            if (UNIVERSAL::isa($actions, 'ARRAY')) {
+                @actions = @$actions;
+            } else {
+                @actions = ($actions);
+            }
+            foreach my $action (@actions) {
+                exists $valid_permission_actions{$action} 
+                    or croak "Action passed to AddPermission must be one of " 
+                     . join(', ', sort keys %valid_permission_actions);
+            
+                $params{"AWSAccountId.$i"} = $account_id;
+                $params{"ActionName.$i"}   = $action;
+                $i++;
+            }
+        }
+        my $href = $self->_dispatch(\%params);
+    }
+}
+
+sub RemovePermission {
+    my ($self, $label, %params) = @_;
+    
+    if ($self->_api_version eq +SQS_VERSION_2008_01_01) {
+        carp "RemovePermission not supported in this API version";
+    }
+    else {
+        $params{Action} = 'RemovePermission';
+        $params{Label}  = $label;
+        my $href = $self->_dispatch(\%params);
+    }
+}
+
 sub GetAttributes {
     my ($self, %params) = @_;
     
-    $params{Action}          = 'GetQueueAttributes';
+    $params{Action} = 'GetQueueAttributes';
 
     my %result;
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        $params{Attribute} ||= 'All';
-    
-        my $href = $self->_dispatch(\%params, [ 'AttributedValue' ]);
+    # default to the current version
+    $params{AttributeName} ||= 'All';
 
-        if ($href->{'AttributedValue'}) {
-            foreach my $attr (@{$href->{'AttributedValue'}}) {
-                $result{$attr->{Attribute}} = $attr->{Value};
-            }
+    my $href = $self->_dispatch(\%params, [ 'Attribute' ]);
+
+    if ($href->{GetQueueAttributesResult}) {
+        foreach my $attr (@{$href->{GetQueueAttributesResult}{Attribute}}) {
+            $result{$attr->{Name}} = $attr->{Value};
         }
     }
-    else {
-        # default to the current version
-        $params{AttributeName} ||= 'All';
-    
-        my $href = $self->_dispatch(\%params, [ 'Attribute' ]);
-
-        if ($href->{GetQueueAttributesResult}) {
-            foreach my $attr (@{$href->{GetQueueAttributesResult}{Attribute}}) {
-                $result{$attr->{Name}} = $attr->{Value};
-            }
-        }
-    }
-    
     return \%result;
 }
 
@@ -137,15 +164,8 @@ sub SetAttribute {
     my ($self, $key, $value, %params) = @_;
     
     $params{Action}             = 'SetQueueAttributes';
-    if ($self->_api_version() eq +SQS_VERSION_2007_05_01) {
-        $params{Attribute} = $key;
-        $params{Value}     = $value;
-    }
-    else {
-        # default to the current version
-        $params{'Attribute.Name'}   = $key;
-        $params{'Attribute.Value'}  = $value;
-    }
+    $params{'Attribute.Name'}   = $key;
+    $params{'Attribute.Value'}  = $value;
     
     my $href = $self->_dispatch(\%params);
 }
@@ -231,6 +251,29 @@ and 10 inclusive. Default is 1.
 
 Delete the message with the specified receipt handle from the queue
 
+=item B<ChangeMessageVisibility($receipt_handle, $timeout, [%opts])>
+
+NOT SUPPORTED IN APIs EARLIER THAN 2009-01-01
+
+Changes the visibility of the message with the specified receipt handle to
+C<$timeout> seconds. C<$timeout> must be in the range 0..43200.
+
+=item B<AddPermission($label, $account_actions, [%opts])>
+
+NOT SUPPORTED IN APIs EARLIER THAN 2009-01-01
+
+Sets a permissions policy with the specified label. C<$account_actions>
+is a reference to a hash mapping 12-digit AWS account numbers to the action(s)
+you want to permit for those account IDs. The hash value for each key can 
+be a string (e.g. "ReceiveMessage") or a reference to an array of strings 
+(e.g. ["ReceiveMessage", "DeleteMessage"])
+
+=item B<RemovePermission($label, [%opts])>
+
+NOT SUPPORTED IN APIs EARLIER THAN 2009-01-01
+
+Removes the permissions policy with the specified label.
+
 =item B<GetAttributes([%opts])>
 
 Get the attributes for the queue. Returns a reference to a hash
